/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.console.pages.panels;

import org.apache.syncope.client.to.RoleTO;
import org.apache.syncope.console.pages.Roles.RoleSummaryUpdateEvent;
import org.apache.syncope.console.rest.RoleRestClient;
import org.apache.syncope.console.wicket.markup.html.tree.TreeActionLinkPanel;
import org.apache.wicket.PageReference;
import org.apache.wicket.event.IEvent;
import org.apache.wicket.extensions.ajax.markup.html.modal.ModalWindow;
import org.apache.wicket.markup.html.panel.Fragment;
import org.apache.wicket.markup.html.panel.Panel;
import org.apache.wicket.model.CompoundPropertyModel;
import org.apache.wicket.spring.injection.annot.SpringBean;

public class RoleSummaryPanel extends Panel {

    private static final long serialVersionUID = 643769814985593156L;

    @SpringBean
    private RoleRestClient restClient;

    private RoleTO selectedNode;

    private Fragment fragment;

    private RoleTabPanel roleTabPanel;

    private TreeActionLinkPanel actionLink;

    private PageReference pageRef;

    private ModalWindow window;

    public RoleSummaryPanel(final String id, final ModalWindow window, final PageReference pageRef) {
        super(id);

        this.pageRef = pageRef;
        this.window = window;

        fragment = new Fragment("rolePanel",
                this.selectedNode == null
                ? "fakerootFrag"
                : (this.selectedNode.getId() == 0 ? "rootPanel" : "roleViewPanel"),
                this);

        if (this.selectedNode != null) {
            if (this.selectedNode.getId() == 0) {
                actionLink = new TreeActionLinkPanel("actionLink", this.selectedNode.getId(),
                        new CompoundPropertyModel(this.selectedNode), window, pageRef);
                fragment.add(actionLink);
            } else {
                roleTabPanel = new RoleTabPanel("nodeViewPanel", selectedNode, window, pageRef);
                roleTabPanel.setOutputMarkupId(true);
                fragment.add(roleTabPanel);
            }
        }

        add(fragment);
    }

    public RoleTO getSelectedNode() {
        return selectedNode;
    }

    @Override
    public void onEvent(final IEvent<?> event) {
        super.onEvent(event);

        if (event.getPayload() instanceof RoleSummaryUpdateEvent) {
            final RoleSummaryUpdateEvent update = (RoleSummaryUpdateEvent) event.getPayload();

            fragment = new Fragment("rolePanel", (update.getSelectedNodeId() == 0
                    ? "rootPanel" : "roleViewPanel"), this);

            if (update.getSelectedNodeId() == 0) {
                actionLink = new TreeActionLinkPanel("actionLink", update.getSelectedNodeId(),
                        new CompoundPropertyModel(this.selectedNode), window, pageRef);
                actionLink.setOutputMarkupId(true);
                fragment.addOrReplace(actionLink);
            } else {
                this.selectedNode = restClient.readRole(update.getSelectedNodeId());
                roleTabPanel = new RoleTabPanel("nodeViewPanel", this.selectedNode, window, pageRef);
                roleTabPanel.setOutputMarkupId(true);
                fragment.addOrReplace(roleTabPanel);
            }

            replace(fragment);
            update.getTarget().add(this);
        }
    }
}